Documentation
¶
Index ¶
- type Client
- func (c *Client) CreateEncryptedImage(encryptedData []byte, onetime bool) (string, error)
- func (c *Client) CreateImage(imageData []byte, filename string, onetime bool) (string, error)
- func (c *Client) CreateLink(url string, encrypted bool, onetime bool) (string, error)
- func (c *Client) CreatePaste(content string, language string, encrypted bool, onetime bool) (string, error)
- func (c *Client) CreateSecret(encryptedData string) (string, error)
- func (c *Client) GetIP() (string, error)
- func (c *Client) GetImage(short string) (string, error)
- func (c *Client) GetImageRaw(short string) ([]byte, error)
- func (c *Client) GetLink(short string) (*models.LinkResponse, error)
- func (c *Client) GetPaste(short string) (string, error)
- func (c *Client) GetPasteRaw(short string) (string, error)
- func (c *Client) GetSecret(short string) (string, error)
- func (c *Client) GetVersion() (*models.VersionResponse, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client handles API requests to the seqre server
func (*Client) CreateEncryptedImage ¶ added in v0.4.0
CreateEncryptedImage uploads an encrypted image blob
func (*Client) CreateImage ¶ added in v0.4.0
CreateImage uploads a raw image file
func (*Client) CreateLink ¶
CreateLink creates a shortened URL
func (*Client) CreatePaste ¶ added in v0.5.0
func (c *Client) CreatePaste(content string, language string, encrypted bool, onetime bool) (string, error)
CreatePaste creates a new text paste
func (*Client) CreateSecret ¶
CreateSecret creates a new secret and returns the full URL
func (*Client) GetImage ¶ added in v0.4.0
GetImage retrieves an encrypted image by short code (returns base64 encoded data)
func (*Client) GetImageRaw ¶ added in v0.4.0
GetImageRaw retrieves a raw (unencrypted) image by short code
func (*Client) GetLink ¶
func (c *Client) GetLink(short string) (*models.LinkResponse, error)
GetLink retrieves link information by short code
func (*Client) GetPaste ¶ added in v0.5.0
GetPaste retrieves an encrypted paste by short code (returns base64 encoded data)
func (*Client) GetPasteRaw ¶ added in v0.5.0
GetPasteRaw retrieves a raw (unencrypted) paste by short code
func (*Client) GetVersion ¶
func (c *Client) GetVersion() (*models.VersionResponse, error)
GetVersion retrieves the server version information